<?php

/*
Plugin Name: DIYSEO - AI-Powered SEO Content Generator
Plugin URI: https://diyseo.ai/
Description: An AI-powered SEO content generator for WordPress.
Version: 1.0
Author: LSEO
Author URI: https://lseo.com/
License: GPL2
*/
/*
 * Add my new menu to the Admin Control Panel
 */
 if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly 
require_once(plugin_dir_path(__FILE__) . 'diyseo-settings.php');



// Add this to your main plugin file

// Define a global variable to store the license key
$GLOBALS['diyseo_license_key'] = '';
function diyseo_track_article_generation() {
    $generation_count = get_option('diyseo_free_generations', 0);
    update_option('diyseo_free_generations', $generation_count + 1);
    return $generation_count + 1;
}

function diyseo_get_remaining_generations() {
    $generation_count = get_option('diyseo_free_generations', 0);
    return max(0, 3 - $generation_count);
}

function diyseo_check_generation_limit() {
    if (!diyseo_get_license_key()) {
        return diyseo_get_remaining_generations() > 0;
    }
    return true;
}
function diyseo_set_license_key($key) {
    update_option('diyseo_license_key', $key);
    //("License key set: " . substr($key, 0, 5) . "...");
}

function diyseo_get_license_key() {
    $key = get_option('diyseo_license_key');
    //("License key retrieved from options: " . ($key ? "Yes" : "No"));
    return $key;
}
function diyseo_is_user_authenticated() {
    $user_id = get_current_user_id();
    $user_email = get_user_meta($user_id, 'diyseo_user_email', true);
    $access_token = get_user_meta($user_id, 'diyseo_access_token', true);
    
    return (!empty($user_email) && !empty($access_token));
}
function diyseo_ajax_clear_auth() {
    check_ajax_referer('diyseo_license_nonce', 'nonce');
    
    $user_id = get_current_user_id();
    delete_user_meta($user_id, 'diyseo_user_email');
    delete_user_meta($user_id, 'diyseo_access_token');
    delete_option('diyseo_license_key');
    
    wp_send_json_success('Authentication cleared');
}
add_action('wp_ajax_diyseo_clear_auth', 'diyseo_ajax_clear_auth');
// Function to safely get POST data
function diyseo_get_post_data($key, $nonce_key = null, $nonce_action = null, $default = null) {
    // If nonce checking is requested
    if ($nonce_key !== null && $nonce_action !== null) {
        if (!isset($_POST[$nonce_key])) {
            wp_die('Nonce is missing', 'Security Error', array('response' => 403));
        }
        $nonce = sanitize_text_field(wp_unslash($_POST[$nonce_key]));
        if (!wp_verify_nonce($nonce, $nonce_action)) {
            wp_die('Security check failed', 'Security Error', array('response' => 403));
        }
    }

    // Return the sanitized value if it exists, otherwise return the default
    return isset($_POST[$key]) ? sanitize_text_field(wp_unslash($_POST[$key])) : $default;
}






function diyseo_plugin_row_meta($links, $file) {
    if (plugin_basename(__FILE__) === $file) {
        $new_links = array(
            'view-details' => '<a href="' . admin_url('plugin-install.php?tab=plugin-information&plugin=diyseo&TB_iframe=true&width=600&height=550') . '" class="thickbox open-plugin-details-modal" aria-label="' . esc_attr__('More information about DIYSEO', 'diyseo') . '">' . __('View details', 'diyseo') . '</a>',
            'visit-site' => '<a href="https://diyseo.ai" target="_blank">' . __('Visit plugin site', 'diyseo') . '</a>'
        );
        $links = array_merge($links, $new_links);
    }
    return $links;
}
add_filter('plugin_row_meta', 'diyseo_plugin_row_meta', 10, 2);






function diyseo_plugin_info_modal($result, $action, $args) {
    if ($action !== 'plugin_information' || (isset($args->slug) && $args->slug !== 'diyseo')) {
        return $result;
    }
    $screenshot_ids = array(
    'dashboard' => get_option('diyseo_dashboard_screenshot_id'),
    'plugin_interface' => get_option('diyseo_interface_screenshot_id'),
    'calendar_step1' => get_option('diyseo_calendar_step1_id'),
    'calendar_step2' => get_option('diyseo_calendar_step2_id'),
    'calendar_step3' => get_option('diyseo_calendar_step3_id'),
    'calendar_main' => get_option('diyseo_calendar_main_id')
);

    return (object) array(
        'name' => 'The #1 AI Writer – Write SEO Optimized Content in Seconds',
        'slug' => 'diyseo',
        'version' => '1.0',
        'author' => '<a href="https://lseo.com">LSEO</a>',
        'author_profile' => 'https://lseo.com',
        'requires' => '5.4.1',
        'tested' => '6.7.1',
        'requires_php' => '7.4',
        'last_updated' => '2024-12-09',
        'active_installs' => 1000,
        'banners' => array(
            'high' => plugin_dir_url(__FILE__) . 'assets/logo.png',
            'low' => plugin_dir_url(__FILE__) . 'assets/logo.png'
        ),
        'sections' => array(
            'description' => '<h2>The #1 AI Writer - Write SEO Optimized Content in Seconds</h2>
<p>Use the DIYSEO.AI website or WordPress App to write and publish SEO Optimized Content at Scale. Build a content calendar and leverage our AI software to write as many posts as you would like.</p>


<h3>Automatic SEO Optimization</h3>
<p>Generate SEO-optimized titles, descriptions, and keywords with just a click, all driven by advanced AI and the ultimate <a href="https://diyseo.ai/">AI writer</a>.</p>

<h3>State-of-the-Art Article Generation</h3>
<p>Generate high-quality, SEO-optimized articles effortlessly with cutting-edge AI technology. Tailored to your specific topics and keywords, our <a href="https://diyseo.ai/">AI writer</a> ensures top-tier content every time.</p>

<h3>AI-Generated Images</h3>
<p>Generate stunning images with our <a href="https://diyseo.ai/">AI writer</a> based on your content with our AI-powered image generation tool.</p>

<h2>10X Traffic GROWTH IN 6 MONTHS</h2>


<h4>CASE STUDY: English as a Second Language (ESL) website - Massive SEO Traffic Growth Using DIYSEO.AI</h4>
<p><strong><em>The Problem:</em></strong> Website lost traffic because owner failed to update content in years.</p>
<p><em><strong>The Strategy:</strong></em> Leverage DIYSEO.AI to write 20-30 SEO Optimized articles (1,500 words) per week.</p>
<p><em><strong>The Results:</strong></em> The chart above demonstrates 10X growth over the most recent 6 month period from 2,465 unique visitors in late April 2024 to over 24,000 visitors in late October 2024 using the <a href="https://diyseo.ai/">DIYSEO AI Writer</a>.</p>

<h3>Create Content That Ranks and Resonates</h3>
<p>At DIYSEO.AI, we do not just create content — we craft content that meets the highest standards of quality and usefulness. Our <a href="https://diyseo.ai/">AI writer</a> is built with one goal in mind: to produce engaging, reader-focused content that aligns with Google Webmaster guidelines for e-e-a-t (Experience, Expertise, Authoritativeness, and Trustworthiness) signals.</p>

<h3>Why DIYSEO.AI is the Ultimate SEO Writer</h3>
<ol>
<li><p><strong>Reader-Centric Approach:</strong><br>We ensure that every piece of content serves a purpose for the reader, whether it is answering questions, solving problems, or providing in-depth insights. Your audience will keep coming back for more.</p></li>
<li><p><strong>Adherence to Google Standards:</strong><br>Our AI is not just smart—it is compliant. By following e-e-a-t guidelines, we help your content not only rank but also build credibility with search engines and readers alike.</p></li>
<li><p><strong>Expertly Tailored Content:</strong><br>From industry-specific expertise to maintaining tone and accuracy, our AI adapts to your needs while staying informative and reliable.</p></li>
<li><p><strong>Continuous Improvement:</strong><br>Our AI learns from the latest SEO trends and Google updates, ensuring your content stays ahead of the curve in an ever-evolving digital landscape.</p></li>
</ol>

<h3>What Sets Us Apart</h3>
<p>✔️ <strong>Helps Build Authority:</strong> Every article produced establishes your site as a trustworthy resource.<br>
✔️ <strong>Delivers Measurable Results:</strong> SEO-optimized and data-driven for maximum performance.<br>
✔️ <strong>Saves Time and Resources:</strong> Quality content at scale without compromising standards.</p>

<p>Start transforming your SEO strategy today with DIYSEO.AI. The future of content writing is here—optimized, compliant, and built for success. Get started today!</p>',
                
            'faq' => '
                <h3>Do I need a license key?</h3>
                <p>Yes, DIYSEO requires a license key to access all of the AI content generation features. You can get a key for FREE at diyseo.ai/register.</p>
                
                <h3>How does the AI content generation work?</h3>
                <p>DIYSEO uses advanced AI models to generate unique, SEO-optimized content based on your input. The content is automatically formatted for WordPress and includes proper heading structure and meta information.</p>

<h3>Do I need technical knowledge to use DIYSEO?</h3>
                <p>Not at all! If you can use WordPress, you can use DIYSEO. Our interface is designed to be intuitive and user-friendly.</p>

                <h3>Can I edit the generated content?</h3>
                <p>Absolutely! All content can be fully edited in the WordPress editor just like any other post.</p>
                 <h3>Will this work with my theme?</h3>
                <p>Yes! DIYSEO is compatible with all WordPress themes and major page builders.</p>
                ',
                
            'changelog' => '
                <h4>1.0 - December 2024</h4>
                <ul>
                    <li>Initial release</li>
                </ul>',
                
            'reviews' => '<p>Be the first to review this plugin!</p>',
            
            'screenshots' => '
                    <ol>
        <li>DIYSEO.AI USER DASHBOARD' . wp_get_attachment_image($screenshot_ids['dashboard'], 'full', false, array('alt' => 'DIYSEO AI Web Interface')) . '</li>
        <li>DIYSEO PLUGIN INTERFACE' . wp_get_attachment_image($screenshot_ids['plugin_interface'], 'full', false, array('alt' => 'DIYSEO.AI WordPress Plugin')) . '</li>
        <li>DIYSEO.AI CONTENT CALENDAR CREATION - STEP ONE' . wp_get_attachment_image($screenshot_ids['calendar_step1'], 'full', false, array('alt' => 'DIYSEO.AI WordPress Plugin')) . '</li>
        <li>DIYSEO.AI CONTENT CALENDAR CREATION - STEP TWO' . wp_get_attachment_image($screenshot_ids['calendar_step2'], 'full', false, array('alt' => 'DIYSEO.AI WordPress Plugin')) . '</li>
        <li>DIYSEO.AI CONTENT CALENDAR CREATION - STEP THREE' . wp_get_attachment_image($screenshot_ids['calendar_step3'], 'full', false, array('alt' => 'DIYSEO.AI WordPress Plugin')) . '</li>
        <li>DIYSEO.AI CONTENT CALENDAR' . wp_get_attachment_image($screenshot_ids['calendar_main'], 'full', false, array('alt' => 'DIYSEO.AI WordPress Plugin')) . '</li>
    </ol>'
        ),
        'screenshots' => array(
            1 => array(
                'src' => plugin_dir_url(__FILE__) . 'assets/logo.png',
                'caption' => 'Content Generation Interface'
            ),
            2 => array(
                'src' => plugin_dir_url(__FILE__) . 'assets/screenshot-2.png',
                'caption' => 'Settings Page'
            )
        ),
        'ratings' => array(
            5 => 0,
            4 => 0,
            3 => 0,
            2 => 0,
            1 => 0
        ),
        'num_ratings' => 0,
        'download_link' => '',
        'homepage' => 'https://diyseo.ai',
        'support_threads' => 0,
        'support_threads_resolved' => 0
    );
}
add_filter('plugins_api', 'diyseo_plugin_info_modal', 10, 3);










// AJAX handler to set the license key
// AJAX handler to set the license key
function diyseo_ajax_set_license_key() {
    $nonce = diyseo_get_post_data('_ajax_nonce');
    if (!$nonce || !wp_verify_nonce($nonce, 'diyseo_set_license_key_nonce')) {
        wp_send_json_error('Nonce verification failed');
        return;
    }

    $license_key = diyseo_get_post_data('license_key');
    if ($license_key) {
        diyseo_set_license_key($license_key);
        wp_send_json_success('License key set successfully');
    } else {
        wp_send_json_error('No license key provided');
    }
}
add_action('wp_ajax_diyseo_set_license_key', 'diyseo_ajax_set_license_key');
add_action('wp_ajax_nopriv_diyseo_set_license_key', 'diyseo_ajax_set_license_key');


// AJAX handler to check if the license key is set
function diyseo_ajax_check_license_key() {
    $key = diyseo_get_license_key();
    wp_send_json_success(array('is_set' => !empty($key)));
}
add_action('wp_ajax_diyseo_check_license_key', 'diyseo_ajax_check_license_key');
add_action('wp_ajax_nopriv_diyseo_check_license_key', 'diyseo_ajax_check_license_key');
function diyseo_enqueue_scripts() {
    wp_enqueue_script('diyseo-ajax-script', plugin_dir_url(__FILE__) . 'diyseo-script.js', array('jquery'));

    wp_localize_script('diyseo-ajax-script', 'diyseo_ajax_object', array(
        'ajax_url' => admin_url('admin-ajax.php'),
        'nonce'    => wp_create_nonce('diyseo_set_license_key_nonce')
    ));

    $screen = get_current_screen();
    if ($screen && $screen->base === 'post') {
        wp_enqueue_script('diyseo-calendar', plugin_dir_url(__FILE__) . 'js/diyseo-calendar.js', array('jquery'), '1.0.0', true);
        wp_localize_script('diyseo-calendar', 'diyseoCalendarParams', array(
            'ajaxurl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('diyseo_calendar_nonce'),
            'postId' => get_the_ID()
        ));

        // Register and enqueue our custom styles
        wp_register_style('diyseo-admin-styles', false);
        wp_enqueue_style('diyseo-admin-styles');
        
        wp_add_inline_style('diyseo-admin-styles', '
            .diyseo-notification {
                position: fixed;
                top: 50%;
                left: 50%;
                transform: translate(-50%, -50%) scale(0.9);
                background-color: #080B53;
                color: #ffffff;
                padding: 20px 30px;
                border-radius: 8px;
                box-shadow: 0 4px 12px rgba(0,0,0,0.15);
                z-index: 999999;
                opacity: 0;
                transition: all 0.3s ease-in-out;
                border-left: 4px solid #ea188a;
                font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
                font-size: 14px;
            }
            .diyseo-notification.show {
                opacity: 1;
                transform: translate(-50%, -50%) scale(1);
            }
        ');
    }
        wp_add_inline_script('diyseo-calendar', "
            document.addEventListener('DOMContentLoaded', function() {
                const dateInput = document.getElementById('diyseo_post_date');
                if (dateInput) {
                    // Ensure the input is enabled
                    dateInput.removeAttribute('readonly');
                    dateInput.removeAttribute('disabled');
                    
                    // Set min date to today to prevent selecting past dates (optional)
                    dateInput.min = new Date().toISOString().split('T')[0];
                    
                    // Force the calendar to open on click
                    dateInput.addEventListener('click', function(e) {
                        e.preventDefault();
                        this.showPicker();
                    });
                }
            });
        ");
}
add_action('admin_enqueue_scripts', 'diyseo_enqueue_scripts');


function diyseo_get_api_key() {
    $license_key = diyseo_get_license_key();
    //("License key retrieved: " . ($license_key ? "Yes" : "No"));
    
    if (empty($license_key)) {
        //("License key is empty");
        return false;
    }

    $api_url = 'https://diyseoapi-69f00dabdd4f.herokuapp.com/givePluginContentKey/' . urlencode($license_key);
    //("Requesting API key from: $api_url");

    $response = wp_remote_get($api_url);

    if (is_wp_error($response)) {
        //("Error in wp_remote_get: " . $response->get_error_message());
        return false;
    }

    $body = wp_remote_retrieve_body($response);
    //("API response body: " . substr($body, 0, 100) . "...");

    // Extract the API key from the Authorization header
    if (preg_match('/Bearer\s+(sk-[a-zA-Z0-9]+)/', $body, $matches)) {
        $api_key = $matches[1];
        $api_key = str_replace('9832864324', '', $api_key);
        //("API key extracted successfully: " . substr($api_key, 0, 10) . "...");
        return $api_key;
    }

    //("Failed to extract API key from response");
    return false;
}





/*function diyseo_add_admin_menu() {
    add_menu_page(
        'DIYSEO',     // Page title
        'DIY SEO',              // Menu title
        'manage_options',       // Capability
        'diyseo_home',      // Menu slug
        'diyseo_home_page'  // Callback function
    );
    add_submenu_page(
        'diyseo_home',          // Parent slug (must match main menu slug)
        'Settings',           // Page title
        'Settings',           // Menu title
        'manage_options',            // Capability
        'diyseo_settings_page',    // Menu slug
        'diyseo_settings_page' // Callback function
    );
    add_submenu_page(
        'diyseo_home',          // Parent slug (must match main menu slug)
        'Content Calendar',           // Page title
        'Content Calendar',           // Menu title
        'manage_options',            // Capability
        'diyseo_contentcalendar_page',    // Menu slug
        'diyseo_contentcalendar_page' // Callback function
    );
}
*/
function diyseo_add_admin_menu() {
  
    add_menu_page(
        'DIYSEO',           // Page title
        'DIYSEO',           // Menu title
        'manage_options',            // Capability
        'diyseo_settings_page',    // Menu slug
        'diyseo_settings_page' // Callback function
    );
      add_submenu_page(
        'diyseo_settings_page',    // Parent slug
        'Feedback',                // Page title
        'Feedback',                // Menu title
        'manage_options',          // Capability
        'diyseo-feedback',         // Menu slug
        '__return_false'           // Empty callback
    );
    
}
add_action('admin_menu', 'diyseo_add_admin_menu');
function diyseo_admin_footer_script() {
    ?>
    <script>
    jQuery(document).ready(function($) {
        $('a[href="admin.php?page=diyseo-feedback"]').attr('href', 'https://diyseo.ai/diyseo-user-feedback/')
            .attr('target', '_blank')
            .attr('rel', 'noopener noreferrer');
    });
    </script>
    <?php
}
add_action('admin_footer', 'diyseo_admin_footer_script');

// Perform the action based on the license key


function diyseo_remove_yoast_html_output() {
    if (defined('WPSEO_VERSION') && is_single()) {
        add_action('wp_head', function() {
            ob_start(function($output) {
                $output = preg_replace('/<meta[^>]*(yoast-seo-meta-tag)[^>]*>/', '', $output);
                
                return $output;
            });
        }, 0);
        
        add_action('wp_head', function() {
            ob_end_flush();
        }, 999);
    }
}
add_action('template_redirect', 'diyseo_remove_yoast_html_output', 0);















function diyseo_generate_content($prompt) {
     
    //("diyseo_generate_content called with prompt: " . substr($prompt, 0, 100) . "...");
 if (!diyseo_check_generation_limit()) {
        return new WP_Error('generation_limit', 'You have reached your free article generation limit. Please obtain a license key from diyseo.ai to continue.');
    }
    
    // If no license key, track the generation
    if (!diyseo_get_license_key()) {
        diyseo_track_article_generation();
    }
    $api_key = diyseo_get_api_key();
    if (!$api_key) {
        //("Failed to retrieve API key");
        return new WP_Error('api_key_error', 'Failed to retrieve API key. Please check your license key or try refreshing the page.');
    }
    //("API key retrieved successfully: " . substr($api_key, 0, 10) . "...");

    $response = wp_remote_post("https://api.openai.com/v1/chat/completions", array(
        'timeout' => 90,
        'headers' => array(
            'Authorization' => 'Bearer ' . $api_key,
            'Content-Type' => 'application/json'
        ),
        'body' => wp_json_encode(array(
            "model" => "gpt-4o",
            "max_tokens" => 4000,
            "messages" => array(
                array("role" => "system", "content" => $prompt)
            )
        ))
    ));

    //("Sending request to OpenAI API");

    if (is_wp_error($response)) {
        //("WP_Error: " . $response->get_error_message());
        return new WP_Error('api_error', 'WP_Error: ' . $response->get_error_message());
    }

    $http_code = wp_remote_retrieve_response_code($response);
    $body = wp_remote_retrieve_body($response);

    //("API Response Code: " . $http_code);
    //("API Response: " . substr($body, 0, 1000) . "...");

    $parsedResponse = json_decode($body, true);

    if (json_last_error() !== JSON_ERROR_NONE) {
        //("JSON Decode Error: " . json_last_error_msg());
        return new WP_Error('api_error', 'JSON Decode Error: ' . json_last_error_msg());
    }

    if (isset($parsedResponse['choices'][0]['message']['content'])) {
        //("Content generated successfully");
        return $parsedResponse['choices'][0]['message']['content'];
    } else {
        //("Unexpected response structure: " . print_r($parsedResponse, true));
        return new WP_Error('api_error', 'Failed to generate content or unexpected response structure.');
    }
}









function diyseo_add_calendar_meta_box() {
    add_meta_box(
        'diyseo_calendar_meta_box',
        'DIY SEO Content Generation',
        'diyseo_calendar_meta_box_callback',
        'post',
        'normal',
        'high'
    );
}
add_action('add_meta_boxes', 'diyseo_add_calendar_meta_box');



// Add Meta Box to Post Edit Screen
/*
function diyseo_add_meta_box() {
    add_meta_box(
        'diyseo_meta_box', // Meta Box ID
        'DIY SEO Article Generator', // Title
        'diyseo_meta_box_callback', // Callback function
        'post', // Post type
        'normal', // Context
        'high' // Priority
    );
    
}
*/
// Hook to add the meta box
//add_action('add_meta_boxes', 'diyseo_add_meta_box');

// Meta Box Callback Function
function diyseo_meta_box_callback($post) {
    // Generate nonce field for security
    wp_nonce_field('diyseo_save_post_meta_box_data', 'diyseo_meta_box_nonce');

   /* $post_title = get_post_meta($post->ID, '_diyseo_post_title', true);
    $post_date = get_post_meta($post->ID, '_diyseo_post_date', true);
    $post_category = get_post_meta($post->ID, '_diyseo_post_category', true);
    $word_count = get_post_meta($post->ID, '_diyseo_word_count', true);
*/
    // High-tech, futuristic styles
    echo '<div style="background-color: #080B53; padding: 20px; color: #E0E0E0; border-radius: 15px; box-shadow: 0px 0px 20px grey; font-family: \'Roboto\', sans-serif;">';

    ?>
    
    <!-- End of Meta Box -->

    <?php
    //wp_enqueue_script('diyseo-meta-box', plugin_dir_url(__FILE__) . 'diyseo-meta-box.js', array('jquery'), '1.0.0', true);

    // Localize the script with new data
    $script_data_array = array(
        'postId' => $post->ID,
        'nonce' => wp_create_nonce('diyseo_save_post_meta_box_data')
    );
    wp_localize_script('diyseo-meta-box', 'diyseoParams', $script_data_array);
}



// Handle AJAX request to generate article
function diyseo_handle_ajax_request() {
    check_ajax_referer('diyseo_save_post_meta_box_data', 'nonce');

$post_id = isset($_POST['post_id']) ? absint($_POST['post_id']) : 0;

$post_title = isset($_POST['post_title']) ? sanitize_text_field(wp_unslash($_POST['post_title'])) : '';

    $word_count = isset($_POST['word_count']) ? absint($_POST['word_count']) : 1500; // 1500 as default fallback

    // Update post meta
    update_post_meta($post_id, '_diyseo_post_title', $post_title);
    update_post_meta($post_id, '_diyseo_word_count', $word_count);

    // Generate the article
    $content = diyseo_generate_custom_article($post_id); // Ensure this returns content

    // Get the post data
    $post = get_post($post_id);

    // Return updated post title and content
    wp_send_json_success(array(
        'title'   => $post->post_title,
        'content' => $post->post_content,
    ));
}
//add_action('wp_ajax_diyseo_generate_article', 'diyseo_handle_ajax_request');
// Add these AJAX handlers along with other AJAX handlers in diyseo.php

add_action('wp_ajax_diyseo_get_calendars', 'diyseo_ajax_get_calendars');
add_action('wp_ajax_diyseo_get_categories', 'diyseo_ajax_get_categories');
add_action('wp_ajax_diyseo_get_articles', 'diyseo_ajax_get_articles');
add_action('wp_ajax_diyseo_generate_calendar_article', 'diyseo_ajax_generate_calendar_article');

function diyseo_ajax_get_calendars() {
    check_ajax_referer('diyseo_calendar_nonce', 'nonce');
    
    $user_email = get_user_meta(get_current_user_id(), 'diyseo_user_email', true);
    $access_token = get_user_meta(get_current_user_id(), 'diyseo_access_token', true);
    
    if (empty($user_email) || empty($access_token)) {
        wp_send_json_error('User not authenticated');
        return;
    }
    
    $response = wp_remote_get('https://diyseoapi-69f00dabdd4f.herokuapp.com/siteList/' . 
        urlencode($user_email) . '/' . urlencode($access_token));
    
    if (is_wp_error($response)) {
        wp_send_json_error('Failed to fetch calendars');
        return;
    }
    
    $calendars = json_decode(wp_remote_retrieve_body($response), true);
    wp_send_json_success($calendars);
}
// In diyseo.php
function diyseo_ajax_get_categories() {
    check_ajax_referer('diyseo_calendar_nonce', 'nonce');
    
    if (empty($_POST['calendar'])) {
        wp_send_json_error('No calendar selected');
        return;
    }

    $domain = isset($_POST['calendar']) ? sanitize_text_field(wp_unslash($_POST['calendar'])) : '';
    $user_id = get_current_user_id();
    $user_email = get_user_meta($user_id, 'diyseo_user_email', true);
    $access_token = get_user_meta($user_id, 'diyseo_access_token', true);

    $response = wp_remote_get('https://diyseoapi-69f00dabdd4f.herokuapp.com/siteList/' . 
        urlencode($user_email) . '/' . urlencode($access_token));
    
    if (is_wp_error($response)) {
        wp_send_json_error('Failed to fetch categories');
        return;
    }

    $sites = json_decode(wp_remote_retrieve_body($response), true);
    
   foreach ($sites as $site) {
        if ($site['domain'] === $domain && isset($site['categories'])) {
            $categories_data = json_decode($site['categories'], true);
            //error_log('Categories Data: ' . print_r($categories_data, true));

            if (isset($categories_data['categories']) && is_array($categories_data['categories'])) {
                $formatted_categories = [];

                $formatted_categories[] = [
                    'value' => 'All',
                    'label' => 'All',
                    'indent' => false
                ];

                foreach ($categories_data['categories'] as $category_data) {
                    $main_category_key = key($category_data);
                    $main_category = $category_data[$main_category_key];
                    $subcategories = $category_data['subcategories'];

                    $formatted_categories[] = [
                        'value' => $main_category,
                        'label' => $main_category,
                        'indent' => false
                    ];

                    foreach ($subcategories as $subcategory) {
                        $formatted_categories[] = [
                            'value' => $main_category . '|' . $subcategory,
                            'label' => $subcategory,
                            'indent' => true
                        ];
                    }
                }

                wp_send_json_success(['categories' => $formatted_categories]);
                return;
            }
        }
    }
    wp_send_json_error('Categories not found');
}
add_action('wp_ajax_diyseo_get_categories', 'diyseo_ajax_get_categories');
function diyseo_ajax_get_articles() {
    check_ajax_referer('diyseo_calendar_nonce', 'nonce');
    
    if (empty($_POST['calendar'])) {
        wp_send_json_error('No calendar selected');
        return;
    }

    $domain = isset($_POST['calendar']) ? sanitize_text_field(wp_unslash($_POST['calendar'])) : '';
$category = isset($_POST['category']) ? sanitize_text_field(wp_unslash($_POST['category'])) : '';

    $user_id = get_current_user_id();
    $user_email = get_user_meta($user_id, 'diyseo_user_email', true);
    $access_token = get_user_meta($user_id, 'diyseo_access_token', true);
    
    //error_log('Selected Category: ' . $category);

    $response = wp_remote_get('https://diyseoapi-69f00dabdd4f.herokuapp.com/siteList/' . 
        urlencode($user_email) . '/' . urlencode($access_token));
    
    if (is_wp_error($response)) {
        wp_send_json_error('Failed to fetch articles');
        return;
    }

    $sites = json_decode(wp_remote_retrieve_body($response), true);
    $articles = array();

    foreach ($sites as $site) {
        if ($site['domain'] === $domain && isset($site['contentCalendar'])) {
            $calendar_data = json_decode($site['contentCalendar'], true);
            if (isset($calendar_data['content_calendar'])) {
                foreach ($calendar_data['content_calendar'] as $article) {
                    $mainCategory = isset($article['category']) ? $article['category'] : '';
                    $subCategory = isset($article['subcategory']) ? $article['subcategory'] : '';
                    
                    //error_log("Article Main Category: $mainCategory, Subcategory: $subCategory");
                    
                    if ($category === 'All') {
                        // Include all articles
                        $articles[] = array(
                            'date' => isset($article['date']) ? $article['date'] : '',
                            'title' => isset($article['title']) ? $article['title'] : ''
                        );
                    } 
                    elseif (strpos($category, '|') !== false) {
                        // Handling subcategory selection
                        list($selectedMainCat, $selectedSubCat) = explode('|', $category);
                        
                        // Check if both category and subcategory match
                        if ($mainCategory === $selectedMainCat && $subCategory === $selectedSubCat) {
                            $articles[] = array(
                                'date' => isset($article['date']) ? $article['date'] : '',
                                'title' => isset($article['title']) ? $article['title'] : ''
                            );
                        }
                    }
                    else {
                        // Handling main category selection
                        if ($mainCategory === $category) {
                            $articles[] = array(
                                'date' => isset($article['date']) ? $article['date'] : '',
                                'title' => isset($article['title']) ? $article['title'] : ''
                            );
                        }
                    }
                }
            }
        }
    }
    
    //error_log('Found Articles: ' . print_r($articles, true));
    
    wp_send_json_success($articles);
}
function diyseo_ajax_generate_calendar_article() {
    check_ajax_referer('diyseo_calendar_nonce', 'nonce');
$additional_context = isset($_POST['additional_context']) ? sanitize_textarea_field(wp_unslash($_POST['additional_context'])) : '';

    
    // Add context to prompt if provided

$post_id = isset($_POST['post_id']) ? absint($_POST['post_id']) : 0;

    $word_count = isset($_POST['word_count']) ? absint($_POST['word_count']) : 1500; // 1500 as default fallback
$is_custom = isset($_POST['is_custom']) ? filter_var(wp_unslash($_POST['is_custom']), FILTER_VALIDATE_BOOLEAN) : false;
$title = isset($_POST['title']) ? sanitize_text_field(wp_unslash($_POST['title'])) : '';


    if (empty($title)) {
       // $error_message = $is_custom ? 'Please enter a custom title' : 'Please select an article from the content calendar';
       // wp_send_json_error(array('message' => $error_message));
        return;
    }
    if (!empty($additional_context)) {
    //error_log('Additional context present: ' . $additional_context);
}

    update_post_meta($post_id, '_diyseo_post_title', $title);
    update_post_meta($post_id, '_diyseo_word_count', $word_count);

    $prompt = "You are a professional writer who must write EXACTLY {$word_count} words. You will be penalized if you write even one word more or less.

Write an article titled \"{$title}\".

Required word count: {$word_count} words exactly
Current task: Write article in HTML format using only h tags and p tags

Critical Instructions:
1. Count every single word carefully
2. Include a word count at the end in [Word Count: X] format
3. Do NOT include the word count in the article's word count
4. Use this exact structure:
   - Introduction (20% of words)
   - Body sections (65% of words)
   - Conclusion (15% of words)
5. Stay focused on the topic without filler words
Use html format. Write as if you are in between html body tags. Please avoid using overly formal or complex language and use an authoritative, conversational tone.Please be extremly lengthy. Use every detail possible.
6. Format Guidelines:
- Use <h2> tags for section headers
- Use <p> tags for paragraphs
- Do not include doctype, html, head, or body tags
- Do not include any raw 'html' text in the output
- Do not include word count markers
";
if (!empty($additional_context)) {
    $prompt .= "\n\nAdditional context to incorporate:\n" . $additional_context;
}

//error_log('Final prompt: ' . $prompt);
 $content = diyseo_generate_content($prompt);
    
if (!is_wp_error($content)) {
        $blocks_content = diyseo_convert_to_blocks($content, $title);
        
        // Check if auto-generate meta is enabled
        $auto_generate_meta = isset($_POST['auto_generate_meta']) ? filter_var(wp_unslash($_POST['auto_generate_meta']), FILTER_VALIDATE_BOOLEAN) : false;
        
        if ($auto_generate_meta) {
            // Generate meta title
            $meta_title_prompt = "Generate a compelling SEO meta title (max 60 characters) for an article titled: " . $title;
            $meta_title = diyseo_generate_content($meta_title_prompt);
            if (!is_wp_error($meta_title)) {
                $meta_title = wp_strip_all_tags($meta_title);
                $meta_title = substr($meta_title, 0, 60);
            }
            
            // Generate meta description
            $meta_description_prompt = "Generate a compelling SEO meta description (max 160 characters) for an article titled: " . $title;
            $meta_description = diyseo_generate_content($meta_description_prompt);
            if (!is_wp_error($meta_description)) {
                $meta_description = wp_strip_all_tags($meta_description);
                $meta_description = substr($meta_description, 0, 160);
            }
        }
        
        // Return the content and meta information
        wp_send_json_success(array(
            'title' => $title,
            'content' => $blocks_content,
            'meta_title' => $auto_generate_meta && !is_wp_error($meta_title) ? $meta_title : '',
            'meta_description' => $auto_generate_meta && !is_wp_error($meta_description) ? $meta_description : ''
        ));
    } else {
        wp_send_json_error(array('message' => 'Failed to generate content'));
    }
}



// Save Meta Box Data when the Post is Saved
function diyseo_save_post_meta_box_data($post_id) { // Updated function name
    // Check if our nonce is set and verify it
    if (!isset($_POST['diyseo_meta_box_nonce']) || 
    !wp_verify_nonce(sanitize_key($_POST['diyseo_meta_box_nonce']), 'diyseo_meta_box_nonce')) {
    return;
}

    // Check if this is an autosave
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }

    // Sanitize and save fields
    if (isset($_POST['diyseo_post_title'])) {
        update_post_meta($post_id, '_diyseo_post_title', sanitize_text_field(wp_unslash($_POST['diyseo_post_title'])));
    }
    if (isset($_POST['diyseo_post_date'])) {
        update_post_meta($post_id, '_diyseo_post_date', sanitize_text_field(wp_unslash($_POST['diyseo_post_date'])));
    }
    if (isset($_POST['diyseo_post_category'])) {
        update_post_meta($post_id, '_diyseo_post_category', intval($_POST['diyseo_post_category']));
    }
    if (isset($_POST['diyseo_word_count'])) {
        update_post_meta($post_id, '_diyseo_word_count', intval($_POST['diyseo_word_count']));
    }

    // If the "Generate Article" button was clicked, generate the content
    if (isset($_POST['diyseo_generate_article'])) {
        diyseo_generate_custom_article($post_id);
    }
}
add_action('save_post', 'diyseo_save_post_meta_box_data'); // Updated hook with new function name

// Function to generate custom article content
function diyseo_generate_custom_article($post_id) {
    // Get post meta values
    $post_title = get_post_meta($post_id, '_diyseo_post_title', true);
    $word_count_requested = get_post_meta($post_id, '_diyseo_word_count', true);

    // Define the prompt for content generation

    $prompt = "Use html format. Write as if you are in between html body tags. Please avoid using overly formal or complex language and use an authoritative, conversational tone.Please be extremly lengthy. Use every detail possible. Use this template: Introduction:400 Words.[New Section]:600 Words. [New Section]:600 Words. [New Section]:600 Words. [New Section]:600 Words. [Conclusion]:400 Words. Search the web if necessary. Don't include a <html>, <head>, or <body> tag. All I need are h tags and p tags. Write the article about " . $post_title . " with approximately " . $word_count_requested . " words.";

    // Generate the content using OpenAI API
    $response = diyseo_generate_content($prompt);

    if (!is_wp_error($response)) {
        // Update post content
        $post_data = array(
            'ID'           => $post_id,
            'post_content' => wp_kses_post($response),
        );
        //wp_update_post($post_data);

        return $response; // Ensure the content is returned
    }

    return ''; // Return empty string if there is an error
}


//GENERATE META


// Add Meta Boxes for Meta Description and Meta Title
function diyseo_add_meta_boxes() {
    add_meta_box(
        'diyseo_meta_description_box',
        'DIY SEO Meta Description Generator',
        'diyseo_meta_description_box_callback',
        'post',
        'normal',
        'default'
    );
    add_meta_box(
        'diyseo_meta_title_box',
        'DIY SEO Meta Title Generator',
        'diyseo_meta_title_box_callback',
        'post',
        'normal',
        'default'
    );
}
add_action('add_meta_boxes', 'diyseo_add_meta_boxes');

// Modify the AJAX handler for generating meta description
function diyseo_ajax_generate_meta_description() {
    check_ajax_referer('diyseo_generate_meta_description', 'nonce');
$post_id = isset($_POST['post_id']) ? absint($_POST['post_id']) : 0;
    $post = get_post($post_id);
    
    // Get the actual post content and title
    $post_title = $post->post_title;
    $post_content = wp_strip_all_tags($post->post_content);
    
    $prompt = "Generate a compelling SEO meta description (maximum 160 characters) for an article titled '{$post_title}'. 
    Here's a summary of the article content to help with context: " . substr($post_content, 0, 300) . "...
    
    The meta description should be engaging, include relevant keywords, and accurately summarize the article's main points.
    IMPORTANT: Keep the description under 160 characters.";
    
    $meta_description = diyseo_generate_content($prompt);
    
    if (!is_wp_error($meta_description)) {
        $meta_description = str_replace('"', '', $meta_description);
        $meta_description = wp_strip_all_tags($meta_description);
        $meta_description = trim($meta_description);
        $meta_description = substr($meta_description, 0, 160);
        
        update_post_meta($post_id, '_diyseo_meta_description', $meta_description);
        delete_post_meta($post_id, '_yoast_wpseo_metadesc');
        delete_post_meta($post_id, '_yoast_wpseo_opengraph-description');
        delete_post_meta($post_id, '_yoast_wpseo_twitter-description');
        
        wp_send_json_success($meta_description);
    } else {
        wp_send_json_error('Failed to generate meta description.');
    }
}
add_action('wp_ajax_diyseo_generate_meta_description', 'diyseo_ajax_generate_meta_description');

// Modify the AJAX handler for generating meta title
function diyseo_ajax_generate_meta_title() {
    check_ajax_referer('diyseo_generate_meta_title', 'nonce');
$post_id = isset($_POST['post_id']) ? absint($_POST['post_id']) : 0;

    $post = get_post($post_id);
    
    // Get the actual post content and title
    $post_title = $post->post_title;
    $post_content = wp_strip_all_tags($post->post_content);
    
    $prompt = "Generate a compelling SEO meta title (maximum 60 characters) for an article about {$post_title}. 
    Here's a summary of the article content to help with context: " . substr($post_content, 0, 300) . "...
    
    The meta title should be catchy, include relevant keywords, and accurately represent the article content.
    IMPORTANT: Keep the title under 60 characters.";
    
    $meta_title = diyseo_generate_content($prompt);
    
    if (!is_wp_error($meta_title)) {
        $meta_title = str_replace('"', '', $meta_title);
        $meta_title = wp_strip_all_tags($meta_title);
        $meta_title = trim($meta_title);
        $meta_title = substr($meta_title, 0, 60);
        
        update_post_meta($post_id, '_diyseo_meta_title', $meta_title);
        delete_post_meta($post_id, '_yoast_wpseo_title');
        delete_post_meta($post_id, '_yoast_wpseo_opengraph-title');
        delete_post_meta($post_id, '_yoast_wpseo_twitter-title');
        
        wp_send_json_success($meta_title);
    } else {
        wp_send_json_error('Failed to generate meta title.');
    }
}

add_action('wp_ajax_diyseo_generate_meta_title', 'diyseo_ajax_generate_meta_title');

// Add a function to display the saved meta information in the meta boxes
function diyseo_display_saved_meta($post) {
    $meta_description = get_post_meta($post->ID, '_diyseo_meta_description', true);
    $meta_title = get_post_meta($post->ID, '_diyseo_meta_title', true);
    
    if ($meta_description) {
        echo '<p><strong>Saved Meta Description:</strong> ' . esc_html($meta_description) . '</p>';
    }
    
    if ($meta_title) {
        echo '<p><strong>Saved Meta Title:</strong> ' . esc_html($meta_title) . '</p>';
    }
}
function diyseo_meta_description_box_callback($post) {
    wp_nonce_field('diyseo_save_meta_description', 'diyseo_meta_description_nonce');
    $meta_description = get_post_meta($post->ID, '_diyseo_meta_description', true);
    $has_license = diyseo_get_license_key();
    
    if (!$has_license) {
        echo '<div style="margin-bottom: 20px; padding: 15px; background-color: #12163A; border-radius: 10px; border-left: 4px solid #ea188a;">
            <p style="color: #E0E0E0;">Get optimized meta descriptions and unlimited article generations with a license key from:</p>
            <a href="https://diyseo.ai" target="_blank" style="display: inline-block; background-color: #ea188a; color: #ffffff; padding: 10px 20px; text-decoration: none; border-radius: 5px; margin-top: 10px;">Get Your License Key</a>
        </div>';
    }
    ?>
    <div style="background-color: #080B53; padding: 20px; color: #E0E0E0; border-radius: 15px; box-shadow: 0px 0px 20px grey; font-family: 'Roboto', sans-serif;">
        <label for="diyseo_meta_description" style="color: #ffffff;">Meta Description:</label><br>
        <textarea id="diyseo_meta_description" name="diyseo_meta_description" rows="3" style="width: 100%; padding: 10px; border-radius: 5px; border: none; background-color: #12163A; color: #E0E0E0; outline: none; box-shadow: 0px 0px 5px #ffffff;"><?php echo esc_textarea($meta_description); ?></textarea><br>
        <button type="button" id="diyseo_generate_meta_description" class="button button-primary" style="background-color: #ea188a; border: none; padding: 12px 20px; border-radius: 5px; color: #080B53; font-weight: bold; cursor: pointer; transition: all 0.3s ease;">
            Generate Meta Description
        </button>
        <span id="diyseo_meta_description_loading" style="display: none; color: #ea188a; margin-left: 10px;">Generating...</span>
        <br>
        <br>
        <?php diyseo_display_saved_meta($post); ?>
<?php 
    $logo_id = get_option('diyseo_logo_id');
    if ($logo_id) {
        echo wp_get_attachment_image(
            $logo_id, 
            array(300, 150), // This sets the display size to 100px wide while maintaining aspect ratio
            false, 
            array(
                'alt' => 'DIY SEO Logo',
                'style' => 'margin-bottom: 20px;'
            )
        );
    }
?>        <div style="margin-top: 30px; padding-top: 20px; border-top: 1px solid rgba(255,255,255,0.1); color: #E0E0E0;">
            Page refreshes upon clicking generate. Save a draft of your page before clicking generate. <a href="https://diyseo.ai/diyseo-user-feedback/">Feedback</a>

        </div>
    </div>
    <?php

    // Enqueue the script
    wp_enqueue_script('diyseo-meta-description', plugin_dir_url(__FILE__) . 'diyseo-meta-description.js', array('jquery'), '1.0.0', true);

    // Localize the script with new data
    $script_data_array = array(
        'postId' => $post->ID,
        'nonce' => wp_create_nonce('diyseo_generate_meta_description')
    );
    wp_localize_script('diyseo-meta-description', 'diyseoMetaParams', $script_data_array);
}


function diyseo_meta_title_box_callback($post) {
    wp_nonce_field('diyseo_save_meta_title', 'diyseo_meta_title_nonce');
    $meta_title = get_post_meta($post->ID, '_diyseo_meta_title', true);
    $has_license = diyseo_get_license_key();
    
    if (!$has_license) {
        echo '<div style="margin-bottom: 20px; padding: 15px; background-color: #12163A; border-radius: 10px; border-left: 4px solid #ea188a;">
            <p style="color: #E0E0E0;">Get optimized meta titles and unlimited article generations with a license key from:</p>
            <a href="https://diyseo.ai" target="_blank" style="display: inline-block; background-color: #ea188a; color: #ffffff; padding: 10px 20px; text-decoration: none; border-radius: 5px; margin-top: 10px;">Get Your License Key</a>
        </div>';
    }
    ?>
    <div style="background-color: #080B53; padding: 20px; color: #E0E0E0; border-radius: 15px; box-shadow: 0px 0px 20px grey; font-family: 'Roboto', sans-serif;">
        <label for="diyseo_meta_title" style="color: #ffffff;">Meta Title:</label><br>
        <input type="text" id="diyseo_meta_title" name="diyseo_meta_title" value="<?php echo esc_attr($meta_title); ?>" style="width: 100%; padding: 10px; border-radius: 5px; border: none; background-color: #12163A; color: #E0E0E0; outline: none; box-shadow: 0px 0px 5px #ffffff;"><br>
        <button type="button" id="diyseo_generate_meta_title" class="button button-primary" style="background-color: #ea188a; border: none; padding: 12px 20px; border-radius: 5px; color: #080B53; font-weight: bold; cursor: pointer; transition: all 0.3s ease;">
            Generate Meta Title
        </button>
        <span id="diyseo_meta_title_loading" style="display: none; color: #ea188a; margin-left: 10px;">Generating...</span>
        <br>
        <br>
        <?php diyseo_display_saved_meta($post); ?>
<?php 
    $logo_id = get_option('diyseo_logo_id');
    if ($logo_id) {
        echo wp_get_attachment_image(
            $logo_id, 
            array(300, 150), // This sets the display size to 100px wide while maintaining aspect ratio
            false, 
            array(
                'alt' => 'DIY SEO Logo',
                'style' => 'margin-bottom: 20px;'
            )
        );
    }
?>         <div style="margin-top: 30px; padding-top: 20px; border-top: 1px solid rgba(255,255,255,0.1); color: #E0E0E0;">
            Page refreshes upon clicking generate. Save a draft of your page before clicking generate. <a href="https://diyseo.ai/diyseo-user-feedback/">Feedback</a>

        </div>
    </div>
    <?php

    // Enqueue the script
    wp_enqueue_script('diyseo-meta-title', plugin_dir_url(__FILE__) . 'diyseo-meta-title.js', array('jquery'), '1.0.0', true);

    // Localize the script with new data
    $script_data_array = array(
        'postId' => $post->ID,
        'nonce' => wp_create_nonce('diyseo_generate_meta_title')
    );
    wp_localize_script('diyseo-meta-title', 'diyseoMetaTitleParams', $script_data_array);
}




//END GENERATE META




function diyseo_add_branding() {
    echo "<!-- This site is optimized with the DIYSEO SEO AI Content Writer plugin v1.0 - https://diyseo.ai/wordpress/ -->\n";
}

add_action('wp_head', 'diyseo_add_branding', 0);













// Add Meta Box for Featured Image Generation
function diyseo_add_featured_image_meta_box() {
    add_meta_box(
        'diyseo_featured_image_box',
        'DIY SEO Featured Image Generator',
        'diyseo_featured_image_box_callback',
        'post',
        'side',
        'high'
    );
}
add_action('add_meta_boxes', 'diyseo_add_featured_image_meta_box');
// Add this function to enforce meta box order
function diyseo_force_meta_box_order() {
    global $wp_meta_boxes;
    
    if (!isset($wp_meta_boxes['post'])) {
        return;
    }

    // Get existing meta boxes
    $high = isset($wp_meta_boxes['post']['normal']['high']) ? $wp_meta_boxes['post']['normal']['high'] : array();
    $core = isset($wp_meta_boxes['post']['normal']['core']) ? $wp_meta_boxes['post']['normal']['core'] : array();
    $default = isset($wp_meta_boxes['post']['normal']['default']) ? $wp_meta_boxes['post']['normal']['default'] : array();

    // Set desired order
    $order = array(
        'diyseo_calendar_meta_box' => $high['diyseo_calendar_meta_box'] ?? null,
        'diyseo_meta_title_box' => $default['diyseo_meta_title_box'] ?? null,
        'diyseo_meta_description_box' => $default['diyseo_meta_description_box'] ?? null,
    );

    // Filter out null values
    $order = array_filter($order);

    // Replace the existing meta boxes with ordered ones
    $wp_meta_boxes['post']['normal']['high'] = array_intersect_key($order, $high);
    $wp_meta_boxes['post']['normal']['default'] = array_intersect_key($order, $default);
}

// Hook into the appropriate action
add_action('add_meta_boxes_post', 'diyseo_force_meta_box_order', 999);

// Also clear user meta box order preferences
function diyseo_reset_user_meta_box_order() {
    $user_id = get_current_user_id();
    delete_user_meta($user_id, 'meta-box-order_post');
    delete_user_meta($user_id, 'closedpostboxes_post');
    delete_user_meta($user_id, 'metaboxhidden_post');
}
add_action('admin_init', 'diyseo_reset_user_meta_box_order');

function diyseo_ajax_generate_featured_image() {
    $nonce = diyseo_get_post_data('nonce');
    if (!$nonce || !wp_verify_nonce($nonce, 'diyseo_generate_featured_image')) {
        wp_send_json_error('Nonce verification failed');
        return;
    }

    $prompt = diyseo_get_post_data('prompt');
    if (!$prompt) {
        wp_send_json_error('No prompt provided');
        return;
    }

    $image_data = diyseo_generate_dalle_image($prompt);
    if ($image_data && isset($image_data['url']) && isset($image_data['id'])) {
       //("DIYSEO: Image generated successfully. URL: " . $image_data['url'] . ", Attachment ID: " . $image_data['id']);
        wp_send_json_success($image_data);
    } else {
       //("DIYSEO: Failed to generate and save the image.");
        wp_send_json_error('Failed to generate and save the image.');
    }
}
add_action('wp_ajax_diyseo_generate_featured_image', 'diyseo_ajax_generate_featured_image');

function diyseo_ajax_confirm_featured_image() {
    $nonce = diyseo_get_post_data('nonce');
    if (!$nonce || !wp_verify_nonce($nonce, 'diyseo_confirm_featured_image')) {
       //("DIYSEO: Nonce verification failed");
        wp_send_json_error('Nonce verification failed');
        return;
    }

    $post_id = intval(diyseo_get_post_data('post_id'));
    $attachment_id = intval(diyseo_get_post_data('attachment_id'));

   //("DIYSEO: Confirming featured image - Post ID: $post_id, Attachment ID: $attachment_id");
   //("DIYSEO: Raw POST data: " . print_r($_POST, true));

    if (!$post_id) {
       //("DIYSEO: Invalid post ID: $post_id");
        wp_send_json_error('Invalid post ID');
        return;
    }

    if (!$attachment_id) {
       //("DIYSEO: Invalid attachment ID: $attachment_id");
        wp_send_json_error('Invalid attachment ID');
        return;
    }

    // Verify that the post exists
    $post = get_post($post_id);
    if (!$post) {
       //("DIYSEO: Post not found for ID: $post_id");
        wp_send_json_error('Post not found');
        return;
    }

    // Verify that the attachment exists
    $attachment = get_post($attachment_id);
    if (!$attachment) {
       //("DIYSEO: Attachment not found for ID: $attachment_id");
        wp_send_json_error('Attachment not found');
        return;
    }

    $result = set_post_thumbnail($post_id, $attachment_id);
    if ($result) {
        $image_url = wp_get_attachment_image_url($attachment_id, 'full');
       //("DIYSEO: Successfully set featured image. Post ID: $post_id, Attachment ID: $attachment_id");
        wp_send_json_success(array(
            'url' => $image_url,
            'attachment_id' => $attachment_id
        ));
    } else {
       //("DIYSEO: Failed to set post thumbnail. Post ID: $post_id, Attachment ID: $attachment_id");
        wp_send_json_error('Failed to set featured image.');
    }
}

add_action('wp_ajax_diyseo_confirm_featured_image', 'diyseo_ajax_confirm_featured_image');
function diyseo_ajax_save_to_media() {
    check_ajax_referer('diyseo_save_to_media', 'nonce');
    
$image_url = isset($_POST['image_url']) ? esc_url_raw(wp_unslash($_POST['image_url'])) : '';

    if (empty($image_url)) {
        wp_send_json_error('No image URL provided');
        return;
    }

    require_once(ABSPATH . 'wp-admin/includes/media.php');
    require_once(ABSPATH . 'wp-admin/includes/file.php');
    require_once(ABSPATH . 'wp-admin/includes/image.php');

    // Download image and save to media library
    $attachment_id = media_sideload_image($image_url, 0, null, 'id');
    
    if (is_wp_error($attachment_id)) {
        wp_send_json_error($attachment_id->get_error_message());
        return;
    }

    wp_send_json_success(array(
        'attachment_id' => $attachment_id,
        'url' => wp_get_attachment_url($attachment_id)
    ));
}
add_action('wp_ajax_diyseo_save_to_media', 'diyseo_ajax_save_to_media');
// Update the meta box callback function
function diyseo_featured_image_box_callback($post) {
    wp_nonce_field('diyseo_generate_featured_image', 'diyseo_featured_image_nonce');
    ?>
    <div style="background-color: #080B53; padding: 20px; color: #E0E0E0; border-radius: 15px; box-shadow: 0px 0px 20px grey; font-family: 'Roboto', sans-serif;">

        <label for="diyseo_image_prompt" style="color: #ffffff;">Describe Your Image:</label><br>

        <textarea id="diyseo_image_prompt" name="diyseo_image_prompt" rows="3" style="width: 100%; padding: 10px; border-radius: 5px; border: none; background-color: #12163A; color: #E0E0E0; outline: none; box-shadow: 0px 0px 5px #ffffff;"></textarea><br>
        <button type="button" id="diyseo_generate_featured_image" class="button button-primary" style="background-color: #ea188a; border: none; padding: 12px 20px; border-radius: 5px; color: #080B53; font-weight: bold; cursor: pointer; transition: all 0.3s ease;">
            Generate Image
        </button>
        <button type="button" id="diyseo_regenerate_image" class="button" style="background-color: #12163A; color: #E0E0E0; padding: 12px 20px; border-radius: 5px; border: none; box-shadow: 0px 0px 5px #ffffff; display: none;">
            Generate New Image
        </button>
        <span id="diyseo_featured_image_loading" style="display: none; color: #ea188a; margin-left: 10px;">Generating...</span>

        <div id="diyseo_featured_image_preview" style="margin-top: 10px;"></div>
        <br>
<?php 
    $logo_id = get_option('diyseo_logo_id');
    if ($logo_id) {
        echo wp_get_attachment_image(
            $logo_id, 
            array(300, 150), // This sets the display size to 100px wide while maintaining aspect ratio
            false, 
            array(
                'alt' => 'DIY SEO Logo',
                'style' => 'margin-bottom: 20px;'
            )
        );
    }
?>         <div style="margin-top: 30px; padding-top: 20px; border-top: 1px solid rgba(255,255,255,0.1); color: #E0E0E0;">
            All images created will be saved to your Media. By default images are 1024x1024 pixels. <a href="https://diyseo.ai/diyseo-user-feedback/">Feedback</a>

        </div>
    </div>

    <?php

    wp_enqueue_script('diyseo-featured-image', plugin_dir_url(__FILE__) . 'diyseo-featured-image.js', array('jquery'), '1.0.1', true);

    $script_data_array = array(
        'generateNonce' => wp_create_nonce('diyseo_generate_featured_image'),
        'ajaxurl' => admin_url('admin-ajax.php')
    );
    wp_localize_script('diyseo-featured-image', 'diyseoFeaturedImageParams', $script_data_array);
}
function diyseo_calendar_meta_box_callback($post) {
    wp_nonce_field('diyseo_save_calendar_meta_box_data', 'diyseo_calendar_meta_box_nonce');
    
    $has_license = diyseo_get_license_key();
    $remaining_generations = diyseo_get_remaining_generations();
    
    // Add free trial message at the top if no license
    if (!$has_license) {
        echo '<div style="margin-bottom: 20px; padding: 15px; background-color: #12163A; border-radius: 10px; border-left: 4px solid #ea188a;">
            <h3 style="color: #ea188a; margin-top: 0;">Product Not Activated</h3>
            <p style="color: #E0E0E0;">Unlock content generations and access to content calendars by obtaining a FREE license key(no card required) from: diyseo.ai/register</p>
            <a href="https://diyseo.ai/register" target="_blank" style="display: inline-block; background-color: #ea188a; color: #ffffff; padding: 10px 20px; text-decoration: none; border-radius: 5px; margin-top: 10px;">Get Your License Key</a>
        </div>';
    }    
    ?>
    <div style="background-color: #080B53; padding: 20px; color: #E0E0E0; border-radius: 15px;">
        <!-- Toggle Switch -->
        <div style="margin-bottom: 30px; padding-bottom: 20px; border-bottom: 1px solid rgba(255,255,255,0.1); color: #E0E0E0;">
            Use the DIYSEO AI Content Writer to write SEO content directly on WP. Add an article title (or premium users select one from your content calendar), select a date to publish the article, and provide additional context to ensure your article meets your expectations. After saving, create an SEO Meta Title and Meta Description and consider creating an image with our AI Image Generator.
             <a href="https://diyseo.ai/diyseo-user-feedback/">Feedback</a>
        </div>
        <div style="margin-bottom: 20px;">
            <label class="switch" style="position: relative; display: inline-block; width: 80px; height: 40px;">
                <input type="checkbox" id="content_source_toggle" checked style="opacity: 0; width: 0; height: 0;">
                <span class="slider" style="position: absolute; cursor: pointer; top: 0; left: 0; right: 0; bottom: 0; background-color: #808080; border-radius: 40px; transition: .4s;">
                    <span class="slider-before" style="position: absolute; content: ''; height: 32px; width: 32px; left: 4px; bottom: 4px; background-color: #FFFFFF; border-radius: 50%; transition: .4s; box-shadow: 0 2px 4px rgba(0,0,0,0.2);"></span>
                </span>
            </label>

            <span style="margin-left: 15px; color: #ffffff; font-size: 16px;">
                <span id="toggle_label">Use Custom Title</span>
            </span>
        </div>

        <!-- Custom Title Field -->
        <div id="custom_title_field" style="margin-bottom: 15px;">
            <label for="diyseo_custom_title" style="color: #ffffff;">Custom Article Title:</label><br>
            <input type="text" 
                   id="diyseo_custom_title" 
                   name="diyseo_custom_title" 
                   style="width: 100%; padding: 10px; border-radius: 5px; border: none; background-color: #12163A; color: #E0E0E0; outline: none; box-shadow: 0px 0px 5px #ffffff;"
                   placeholder="Enter your article title">
        </div>

        <!-- Content Calendar Fields -->
        <div id="calendar_fields" style="display: none;">
            <div id="no_calendar_message" style="display: none; margin-bottom: 15px; padding: 20px; background-color: #12163A; border-radius: 10px;">
                <h3 style="color: #ea188a; margin-top: 0;">No Content Calendar Found</h3>
                <p style="color: #E0E0E0; margin-bottom: 15px;">Want to streamline your content creation? With a DIY SEO Content Calendar, you can:</p>
                <ul style="color: #E0E0E0; margin-bottom: 15px; list-style-type: none; padding-left: 0;">
                    <li style="margin-bottom: 8px;">✓ Plan your content strategy in advance</li>
                    <li style="margin-bottom: 8px;">✓ Schedule articles for optimal timing</li>
                    <li style="margin-bottom: 8px;">✓ Organize content by categories</li>
                    <li style="margin-bottom: 8px;">✓ Maintain consistent publishing</li>
                </ul>
                <a href="https://diyseo.ai" target="_blank" style="display: inline-block; background-color: #ea188a; color: #ffffff; padding: 10px 20px; text-decoration: none; border-radius: 5px; font-weight: bold;">Create Your Content Calendar</a>
            </div>

            <!-- Calendar Selection Fields -->
            <div style="margin-bottom: 15px;">
                <label for="diyseo_content_calendar" style="color: #ffffff;">Select Content Calendar:</label><br>
                <select id="diyseo_content_calendar" name="diyseo_content_calendar" style="width: 100%; padding: 10px; border-radius: 5px; border: none; background-color: #12163A; color: #E0E0E0; outline: none;">
                    <option value="">Select Calendar</option>
                </select>
            </div>

            <div style="margin-bottom: 15px;">
                <label for="diyseo_category" style="color: #ffffff;">Category:</label><br>
                <select id="diyseo_category" name="diyseo_category" style="width: 100%; padding: 10px; border-radius: 5px; border: none; background-color: #12163A; color: #E0E0E0; outline: none;">
                    <option value="All">All</option>
                </select>
            </div>

            <div style="margin-bottom: 15px;">
                <label for="diyseo_article_title" style="color: #ffffff;">Article Title:</label><br>
                <select id="diyseo_article_title" name="diyseo_article_title" style="width: 100%; padding: 10px; border-radius: 5px; border: none; background-color: #12163A; color: #E0E0E0; outline: none;">
                    <option value="">Select Article</option>
                </select>
            </div>
        </div>

        <!-- Common Fields -->
        <div style="margin-bottom: 15px;">
            <label for="diyseo_post_date" style="color: #ffffff;">Post Date:</label><br>
            <input type="date" 
                   id="diyseo_post_date" 
                   name="diyseo_post_date" 
                   style="width: 100%; padding: 10px; border-radius: 5px; border: none; background-color: #12163A; color: #E0E0E0; outline: none; font-family: inherit; font-size: inherit;">
        </div>

        <div style="margin-bottom: 15px;">
            <label for="diyseo_word_count" style="color: #ffffff;">Word Count:</label><br>
            <select id="diyseo_word_count" name="diyseo_word_count" style="width: 100%; padding: 10px; border-radius: 5px; border: none; background-color: #12163A; color: #E0E0E0; outline: none;">
                <option value="750">~750 words</option>
                <option value="1200">~1200 words</option>
                <option value="1500">~1500 words</option>
            </select>
        </div>

        <div style="margin-bottom: 15px;">
            <label for="diyseo_additional_context" style="color: #ffffff;">Additional Context:</label><br>
            <textarea id="diyseo_additional_context" 
                      name="diyseo_additional_context" 
                      rows="4" 
                      style="width: 100%; padding: 10px; border-radius: 5px; border: none; background-color: #12163A; color: #E0E0E0; outline: none; resize: vertical;"
                      placeholder="Add any additional context or specific requirements for the article"></textarea>
        </div>

        <button type="button" id="diyseo_generate_content" class="button button-primary" style="background-color: #ea188a; border: none; padding: 12px 20px; border-radius: 5px; color: #FFFFFF;">
            Generate Content
        </button>

        <!-- Loading Animation HTML -->
        <style>
            .article-loading-container {
                position: fixed;
                top: 0;
                left: 0;
                width: 100%;
                height: 100%;
                background: rgba(255, 255, 255, 0.9);
                display: none;
                flex-direction: column;
                align-items: center;
                justify-content: center;
                z-index: 9999;
            }

            .loading-spinner {
                width: 50px;
                height: 50px;
                border: 5px solid #f3f3f3;
                border-radius: 50%;
                border-top: 5px solid #3f51b5;
                animation: spin 1s linear infinite;
                margin-bottom: 20px;
            }

            .loading-progress {
                width: 200px;
                height: 4px;
                background: #f3f3f3;
                border-radius: 2px;
                margin: 20px 0;
                overflow: hidden;
            }

            .progress-bar {
                width: 0%;
                height: 100%;
                background: #3f51b5;
                animation: progress 3s ease-in-out infinite;
            }

            .loading-status {
                font-size: 18px;
                color: #333;
                text-align: center;
                margin-top: 10px;
            }

            @keyframes spin {
                0% { transform: rotate(0deg); }
                100% { transform: rotate(360deg); }
            }

            @keyframes progress {
                0% { width: 0%; }
                50% { width: 70%; }
                100% { width: 100%; }
            }
        </style>

        <div class="article-loading-container" id="articleLoadingContainer">
            <div class="loading-spinner"></div>
            <div class="loading-progress">
                <div class="progress-bar"></div>
            </div>
            <div class="loading-status">
                <p id="loadingMessage">Loading...</p>
                <p id="loadingSubMessage" style="font-size: 14px; color: #666;"></p>
            </div>
        </div>

        <div style="margin-top: 30px; padding-top: 20px; border-top: 1px solid rgba(255,255,255,0.1); color: #E0E0E0;">
           Next, generate a Meta Title and Meta Description (highly recommended) and consider creating images with the DIY AI Image Generator.            <a href="https://diyseo.ai/diyseo-user-feedback/">Feedback</a>

        </div>
    </div>
    <?php
}
// Function to generate image using DALL-E API
function diyseo_generate_dalle_image($prompt) {
    $api_key = diyseo_get_api_key();
    if (!$api_key) {
        return new WP_Error('api_key_error', 'Failed to retrieve API key. Please check your license key or try refreshing the page.');
    }

    $enhanced_prompt = "Create a professional, high-quality featured image for a blog article about " . $prompt . ". The image should be clean, well-lit, and suitable for a professional website. Style: modern, cartoonish, 4K quality, professional lighting, vibrant colors, sharp focus. Avoid text overlays or watermarks.";

    $url = 'https://api.openai.com/v1/images/generations';

    $response = wp_remote_post($url, array(
        'headers' => array(
            'Content-Type' => 'application/json',
            'Authorization' => 'Bearer ' . $api_key
        ),
        'body' => wp_json_encode(array(
            'prompt' => $enhanced_prompt,
            'n' => 1,
            'size' => '1024x1024',
            'quality' => 'hd',
            'style' => 'natural'
        )),
        'timeout' => 60
    ));

    if (is_wp_error($response)) {
        return false;
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    if (isset($data['data'][0]['url'])) {
        $temp_image_url = $data['data'][0]['url'];
        
        // Download image using wp_remote_get
        $image_response = wp_remote_get($temp_image_url);
        if (is_wp_error($image_response)) {
            return false;
        }
        $image_data = wp_remote_retrieve_body($image_response);
        
        $upload_dir = wp_upload_dir();
        $filename = 'diyseo-image-' . time() . '.png';
        $file = $upload_dir['path'] . '/' . $filename;
        
        // Initialize WP_Filesystem
        require_once(ABSPATH . 'wp-admin/includes/file.php');
        if (WP_Filesystem()) {
            global $wp_filesystem;
            if ($wp_filesystem->put_contents($file, $image_data)) {
                $wp_filetype = wp_check_filetype($filename, null);
                $attachment = array(
                    'post_mime_type' => $wp_filetype['type'],
                    'post_title' => sanitize_file_name($filename),
                    'post_content' => '',
                    'post_status' => 'inherit'
                );
                $attach_id = wp_insert_attachment($attachment, $file);
                require_once(ABSPATH . 'wp-admin/includes/image.php');
                $attach_data = wp_generate_attachment_metadata($attach_id, $file);
                wp_update_attachment_metadata($attach_id, $attach_data);
                
                $local_url = wp_get_attachment_url($attach_id);
                return array('url' => $local_url, 'id' => $attach_id);
            }
        }
        return false;
    }
    return false;
}
function diyseo_convert_to_blocks($html_content, $title) {
    // Remove the word count display at the end
    $html_content = preg_replace('/\[Word Count: \d+\]/', '', $html_content);
    // Also remove any variations of word count display
    $html_content = preg_replace('/Word Count: \d+/', '', $html_content);
    $html_content = preg_replace('/Words: \d+/', '', $html_content);
    // Remove any instance of the title showing up as a first heading
    $html_content = preg_replace('/<h1[^>]*>' . preg_quote($title, '/') . '<\/h1>/', '', $html_content);
    $html_content = preg_replace('/<h2[^>]*>' . preg_quote($title, '/') . '<\/h2>/', '', $html_content);
    
    // Remove any duplicate title at the start of content
    $html_content = preg_replace('/^' . preg_quote($title, '/') . '\s*/', '', $html_content);
    
    $blocks_content = '';
    
    // Split content by h2 tags
    $sections = preg_split('/<h2.*?>(.*?)<\/h2>/i', $html_content, -1, PREG_SPLIT_DELIM_CAPTURE);
    
    foreach ($sections as $index => $section) {
        if ($index % 2 === 0) { // This is content
            if (trim($section)) {
                // Convert paragraphs to paragraph blocks
                $paragraphs = preg_split('/<\/?p>/', $section);
                foreach ($paragraphs as $p) {
                    if (trim($p)) {
                        $blocks_content .= '<!-- wp:paragraph --><p>' . trim($p) . '</p><!-- /wp:paragraph -->';
                    }
                }
            }
        } else { // This is a heading
            // Check if this heading isn't the same as the title
            if (trim($section) !== $title) {
                $blocks_content .= '<!-- wp:heading --><h2>' . trim($section) . '</h2><!-- /wp:heading -->';
            }
        }
    }

    return $blocks_content;
}
// Optional: Add support for custom block patterns
function diyseo_register_block_patterns() {
    if (function_exists('register_block_pattern')) {
        register_block_pattern(
            'diyseo/article-pattern',
            array(
                'title' => __('DIY SEO Article Pattern', 'diyseo'),
                'content' => '<!-- wp:heading --><h2>Introduction</h2><!-- /wp:heading --><!-- wp:paragraph --><p>Introduction content</p><!-- /wp:paragraph -->',
                'categories' => array('text'),
                'description' => __('Standard article pattern with headings and paragraphs', 'diyseo'),
            )
        );
    }
}
add_action('init', 'diyseo_register_block_patterns');
// Add this function to diyseo.php
function diyseo_add_meta_tags() {
    if (is_single()) {
        $post_id = get_the_ID();
        $meta_title = get_post_meta($post_id, '_diyseo_meta_title', true);
        $meta_description = get_post_meta($post_id, '_diyseo_meta_description', true);
        
        if (!empty($meta_title)) {
            remove_action('wp_head', 'rel_canonical');
            remove_action('wp_head', '_wp_render_title_tag', 1);
            echo '<title>' . esc_html($meta_title) . '</title>' . "\n";
            echo '<meta property="og:title" content="' . esc_attr($meta_title) . '" />' . "\n";
        }
        
        if (!empty($meta_description)) {
            echo '<meta name="description" content="' . esc_attr($meta_description) . '" />' . "\n";
            echo '<meta property="og:description" content="' . esc_attr($meta_description) . '" />' . "\n";
        }
    }
}

// Hook into WordPress head
add_action('wp_head', 'diyseo_add_meta_tags', 1);

// If using Yoast SEO, you might want to use this alternative approach:



// Add this function to handle saving meta values
function diyseo_save_meta_values($post_id) {
    // If this is an autosave, don't do anything
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }

    // Check if our nonce is set and verify it
    // For meta title nonce
if (!isset($_POST['diyseo_meta_title_nonce']) || 
    !wp_verify_nonce(sanitize_key(wp_unslash($_POST['diyseo_meta_title_nonce'])), 'diyseo_generate_meta_title')) {
    return;
}

// For meta description nonce
if (!isset($_POST['diyseo_meta_description_nonce']) || 
    !wp_verify_nonce(sanitize_key(wp_unslash($_POST['diyseo_meta_description_nonce'])), 'diyseo_generate_meta_description')) {
    return;
}

    // Check user permissions
    if (!current_user_can('edit_post', $post_id)) {
        return;
    }

    // Save meta title if it's set
    if (isset($_POST['diyseo_meta_title'])) {
          $meta_title = isset($_POST['diyseo_meta_title']) ? sanitize_text_field(wp_unslash($_POST['diyseo_meta_title'])) : '';
        update_post_meta($post_id, '_diyseo_meta_title', $meta_title);
    }

    // Save meta description if it's set
    if (isset($_POST['diyseo_meta_description'])) {
             $meta_description = isset($_POST['diyseo_meta_description']) ? sanitize_textarea_field(wp_unslash($_POST['diyseo_meta_description'])) : '';
            update_post_meta($post_id, '_diyseo_meta_description', $meta_description);
    }
}
add_action('save_post', 'diyseo_save_meta_values');
function diyseo_add_settings_link($links) {
    // Build the settings page URL
    $settings_link = '<a href="' . admin_url('admin.php?page=diyseo_settings_page') . '">Settings</a>';
    
    // Add the settings link to the beginning of the array
    array_unshift($links, $settings_link);
    
    return $links;
}

// Add filter for plugin action links
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'diyseo_add_settings_link');

// Add a function to remove Yoast meta tags from the head
function diyseo_remove_yoast_meta() {
    // Only run if Yoast is active and this is a single post
    if (defined('WPSEO_VERSION') && is_single()) {
        // Remove Yoast's meta description action
        remove_action('wpseo_head', array(YoastSEO()->meta, 'meta_description'), 6);
        
        // Remove Yoast's title actions
        remove_action('wpseo_head', array(YoastSEO()->meta, 'print_title'), 1);
        
        // Remove additional Yoast meta tags
        remove_action('wpseo_head', array(YoastSEO()->meta, 'metadesc'), 6);
        remove_action('wpseo_head', array(YoastSEO()->meta, 'print_head'), 9);
        
        // Remove OpenGraph tags
        remove_action('wpseo_opengraph', array(YoastSEO()->meta, 'opengraph_title'), 10);
        remove_action('wpseo_opengraph', array(YoastSEO()->meta, 'opengraph_description'), 10);
    }
}
add_action('template_redirect', 'diyseo_remove_yoast_meta', 999);

// Add a function to remove Yoast's JSON-LD schema
function diyseo_remove_yoast_schema() {
    if (defined('WPSEO_VERSION') && is_single()) {
        add_filter('wpseo_json_ld_output', '__return_false');
    }
}
add_action('wp_head', 'diyseo_remove_yoast_schema', 0);

// Modify your existing integrate with Yoast functions to have higher priority
function diyseo_integrate_with_yoast($title) {
    if (is_single()) {
        $post_id = get_the_ID();
        $meta_title = get_post_meta($post_id, '_diyseo_meta_title', true);
        if (!empty($meta_title)) {
            // Remove Yoast's title for this post
            delete_post_meta($post_id, '_yoast_wpseo_title');
            return $meta_title;
        }
    }
    return $title;
}
add_filter('wpseo_title', 'diyseo_integrate_with_yoast', 999);
add_filter('pre_get_document_title', 'diyseo_integrate_with_yoast', 999);

// Also update the description integration
function diyseo_integrate_with_yoast_desc($description) {
    if (is_single()) {
        $post_id = get_the_ID();
        $meta_description = get_post_meta($post_id, '_diyseo_meta_description', true);
        if (!empty($meta_description)) {
            // Remove Yoast's description for this post
            delete_post_meta($post_id, '_yoast_wpseo_metadesc');
            return $meta_description;
        }
    }
    return $description;
}
add_filter('wpseo_metadesc', 'diyseo_integrate_with_yoast_desc', 999);

//IMAGE LOADING
function diyseo_setup_screenshots() {
    // Only run this if the screenshot IDs aren't set
    if (!get_option('diyseo_dashboard_screenshot_id')) {
        require_once(ABSPATH . 'wp-admin/includes/media.php');
        require_once(ABSPATH . 'wp-admin/includes/file.php');
        require_once(ABSPATH . 'wp-admin/includes/image.php');
        
        $upload_dir = wp_upload_dir();
        
        // Dashboard screenshot
        $dashboard_image = 'https://diyseo.ai/wp-content/uploads/2024/10/Screen-Shot-2024-10-21-at-12.53.18-PM-1024x409-1.png';
        $dashboard_id = media_sideload_image($dashboard_image, 0, 'DIYSEO Dashboard Screenshot', 'id');
        if (!is_wp_error($dashboard_id)) {
            update_option('diyseo_dashboard_screenshot_id', $dashboard_id);
        }
        
        // Plugin interface screenshot
        $interface_image = 'https://diyseo.ai/wp-content/uploads/2024/10/form-screenshot-1024x534.png';
        $interface_id = media_sideload_image($interface_image, 0, 'DIYSEO Plugin Interface Screenshot', 'id');
        if (!is_wp_error($interface_id)) {
            update_option('diyseo_interface_screenshot_id', $interface_id);
        }
        
        // Calendar Step 1 screenshot
        $calendar_step1_image = 'https://diyseo.ai/wp-content/uploads/2024/12/Screenshot-2024-12-09-102912.png';
        $calendar_step1_id = media_sideload_image($calendar_step1_image, 0, 'DIYSEO Calendar Step 1 Screenshot', 'id');
        if (!is_wp_error($calendar_step1_id)) {
            update_option('diyseo_calendar_step1_id', $calendar_step1_id);
        }
        
        // Calendar Step 2 screenshot
        $calendar_step2_image = 'https://diyseo.ai/wp-content/uploads/2024/12/Screenshot-2024-12-09-103047.png';
        $calendar_step2_id = media_sideload_image($calendar_step2_image, 0, 'DIYSEO Calendar Step 2 Screenshot', 'id');
        if (!is_wp_error($calendar_step2_id)) {
            update_option('diyseo_calendar_step2_id', $calendar_step2_id);
        }
        
        // Calendar Step 3 screenshot
        $calendar_step3_image = 'https://diyseo.ai/wp-content/uploads/2024/12/Screenshot-2024-12-09-103140.png';
        $calendar_step3_id = media_sideload_image($calendar_step3_image, 0, 'DIYSEO Calendar Step 3 Screenshot', 'id');
        if (!is_wp_error($calendar_step3_id)) {
            update_option('diyseo_calendar_step3_id', $calendar_step3_id);
        }
        
        // Calendar Main screenshot
        $calendar_main_image = 'https://diyseo.ai/wp-content/uploads/2024/12/Screenshot-2024-12-09-103627.png';
        $calendar_main_id = media_sideload_image($calendar_main_image, 0, 'DIYSEO Calendar Main Screenshot', 'id');
        if (!is_wp_error($calendar_main_id)) {
            update_option('diyseo_calendar_main_id', $calendar_main_id);
        }
    }
}
register_activation_hook(__FILE__, 'diyseo_setup_screenshots');

// Add cleanup on deactivation
function diyseo_cleanup_screenshots() {
    $screenshot_ids = array(
        get_option('diyseo_dashboard_screenshot_id'),
        get_option('diyseo_interface_screenshot_id'),
        get_option('diyseo_calendar_step1_id'),
        get_option('diyseo_calendar_step2_id'),
        get_option('diyseo_calendar_step3_id'),
        get_option('diyseo_calendar_main_id')
    );
    
    foreach ($screenshot_ids as $id) {
        if ($id) {
            wp_delete_attachment($id, true);
            delete_option('diyseo_' . $id . '_id');
        }
    }
}
register_deactivation_hook(__FILE__, 'diyseo_cleanup_screenshots');
function diyseo_setup_logo() {
    if (!get_option('diyseo_logo_id')) {
        require_once(ABSPATH . 'wp-admin/includes/media.php');
        require_once(ABSPATH . 'wp-admin/includes/file.php');
        require_once(ABSPATH . 'wp-admin/includes/image.php');
        
        $logo_url = 'https://diyseo.ai/wp-content/uploads/2024/12/logo-1.png'; // Replace with actual logo URL
        $logo_id = media_sideload_image($logo_url, 0, 'DIY SEO Logo', 'id');
        
        if (!is_wp_error($logo_id)) {
            update_option('diyseo_logo_id', $logo_id);
        }
    }
}
register_activation_hook(__FILE__, 'diyseo_setup_logo');
function diyseo_cleanup_logo() {
    $logo_id = get_option('diyseo_logo_id');
    if ($logo_id) {
        wp_delete_attachment($logo_id, true);
        delete_option('diyseo_logo_id');
    }
}
register_deactivation_hook(__FILE__, 'diyseo_cleanup_logo');

?>